@@ -1,4 +1,4 @@
-# (C) Copyright 2005-2020 Enthought, Inc., Austin, TX
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
@@ -69,8 +69,6 @@ class ETSConfig(object):
         self._kiva_backend = None
         self._user_data = None
 
-        return
-
     ###########################################################################
     # 'ETSConfig' interface.
     ###########################################################################
@@ -117,8 +115,6 @@ class ETSConfig(object):
 
         self._application_data = application_data
 
-        return
-
     def get_application_home(self, create=False):
         """ Return the application home directory path.
 
@@ -177,8 +173,6 @@ class ETSConfig(object):
 
         self._application_home = application_home
 
-        return
-
     application_home = property(_get_application_home, _set_application_home)
 
     def _get_company(self):
@@ -200,8 +194,6 @@ class ETSConfig(object):
 
         self._company = company
 
-        return
-
     company = property(_get_company, _set_company)
 
     @contextmanager
@@ -266,17 +258,16 @@ class ETSConfig(object):
 
         self._toolkit = toolkit
 
-        return
-
     toolkit = property(_get_toolkit, _set_toolkit)
 
     def _get_enable_toolkit(self):
         """
         Deprecated: This property is no longer used.
 
-        Property getter for the Enable backend.  The value returned is, in order
-        of preference: the value set by the application; the value specified by
-        the 'ENABLE_TOOLKIT' environment variable; otherwise the empty string.
+        Property getter for the Enable backend.  The value returned is, in
+        order of preference: the value set by the application; the value
+        specified by the 'ENABLE_TOOLKIT' environment variable; otherwise the
+        empty string.
         """
         from warnings import warn
 
@@ -288,30 +279,30 @@ class ETSConfig(object):
         """
         Deprecated.
 
-        Property setter for the Enable toolkit.  The toolkit can be set more than
-        once, but only if it is the same one each time.  An application that is
-        written for a particular toolkit can explicitly set it before any other
-        module that gets the value is imported.
+        Property setter for the Enable toolkit.  The toolkit can be set more
+        than once, but only if it is the same one each time.  An application
+        that is written for a particular toolkit can explicitly set it before
+        any other module that gets the value is imported.
         """
         from warnings import warn
 
         warn("Use of the enable_toolkit attribute is deprecated.")
 
-        return
-
     enable_toolkit = property(_get_enable_toolkit, _set_enable_toolkit)
 
     def _get_kiva_backend(self):
         """
         Property getter for the Kiva backend. The value returned is dependent
-        on the value of the toolkit property. If toolkit specifies a kiva backend
-        using the extended syntax: <enable toolkit>[.<kiva backend>] then the
-        value of the property will be whatever was specified. Otherwise the
-        value will be a reasonable default for the given enable backend.
+        on the value of the toolkit property. If toolkit specifies a kiva
+        backend using the extended syntax: <enable toolkit>[.<kiva backend>]
+        then the value of the property will be whatever was specified.
+        Otherwise the value will be a reasonable default for the given enable
+        backend.
         """
         if self._toolkit is None:
             raise AttributeError(
-                "The kiva_backend attribute is dependent on toolkit, which has not been set."
+                "The kiva_backend attribute is dependent on toolkit, "
+                "which has not been set."
             )
 
         if self._kiva_backend is None:
@@ -358,8 +349,6 @@ class ETSConfig(object):
 
         self._user_data = user_data
 
-        return
-
     user_data = property(_get_user_data, _set_user_data)
 
     #### private methods #####################################################
@@ -421,7 +410,8 @@ class ETSConfig(object):
             if user is not None:
                 directory_name += "_%s" % user
             warn(
-                'Environment variable "%s" not set, setting home directory to %s'
+                'Environment variable "%s" not set, '
+                'setting home directory to %s'
                 % (environment_variable, parent_directory)
             )
 
@@ -486,9 +476,10 @@ class ETSConfig(object):
                 # naive way...
 
                 # Check if the usr_dir is C:\\John Doe\\Documents and Settings.
-                # If yes, then we should modify the usr_dir to be 'My Documents'.
-                # If no, then the user must have modified the os.environ
-                # variables and the directory chosen is a desirable one.
+                # If yes, then we should modify the usr_dir to be
+                # 'My Documents'. If no, then the user must have modified the
+                # os.environ variables and the directory chosen is a desirable
+                # one.
                 desired_dir = os.path.join(parent_directory, "My Documents")
 
                 if os.path.exists(desired_dir):
