@@ -1,35 +1,35 @@
-# ------------------------------------------------------------------------------
-# Copyright (c) 2005, Enthought, Inc.
+# (C) Copyright 2005-2021 Enthought, Inc., Austin, TX
 # All rights reserved.
 #
 # This software is provided without warranty under the terms of the BSD
-# license included in enthought/LICENSE.txt and may be redistributed only
-# under the conditions described in the aforementioned license.  The license
+# license included in LICENSE.txt and may be redistributed only under
+# the conditions described in the aforementioned license. The license
 # is also available online at http://www.enthought.com/licenses/BSD.txt
-# Thanks for using Enthought open source!
 #
-# Author: Enthought, Inc.
-# Description: <Enthought util package component>
-# ------------------------------------------------------------------------------
-""" Utility functions for managing and finding resources (ie. images/files etc).
+# Thanks for using Enthought open source!
+
+""" Utility functions for managing and finding resources (e.g. images, files).
 
     get_path :           Returns the absolute path of a class or instance
 
     create_unique_name : Creates a name with a given prefix that is not in a
-                         given list of existing names. The separator between the
-                         prefix and the rest of the name can also be specified
-                         (default is a '_')
+                         given list of existing names. The separator between
+                         the prefix and the rest of the name can also be
+                         specified (default is a '_')
 
     find_resource:       Given a setuptools project specification string
                          ('MyProject>=2.1') and a partial path leading from the
                          projects base directory to the desired resource, will
-                         return either an opened file object or, if specified, a
-                         full path to the resource.
+                         return either an opened file object or, if specified,
+                         a full path to the resource.
 """
 
 
 # Standard library imports.
-import inspect, os, sys
+import inspect
+import os
+import sys
+
 from distutils.sysconfig import get_python_lib
 
 
@@ -83,11 +83,20 @@ def create_unique_name(prefix, names, separator="_"):
 def find_resource(project, resource_path, alt_path=None, return_path=False):
     """ Returns a file object or file path pointing to the desired resource.
 
+    This function will find a desired resource file and return an opened file
+    object. The main method of finding the resource uses the pkg_resources
+    resource_stream method, which searches your working set for the installed
+    project specified and appends the resource_path given to the project
+    path, leading it to the file. If setuptools is not installed or it cannot
+    find/open the resource, find_resource will use the sys.path[0] to find the
+    resource if alt_path is defined.
+
     Parameters
     ----------
     project : str
         The name of the project to look for the resource in. Can be the name or
-        a requirement string. Ex: 'MyProject', 'MyProject>1.0', 'MyProject==1.1'
+        a requirement string. Ex: 'MyProject', 'MyProject>1.0',
+        'MyProject==1.1'
     resource_path : str
         The path to the file from inside the package. If the file desired is
         MyProject/data/image.jpg, resource_path would be 'data/image.jpg'.
@@ -107,23 +116,13 @@ def find_resource(project, resource_path, alt_path=None, return_path=False):
         A file object containing the resource. If return_path is True, 'file'
         will be the full path to the resource. If the file is not found or
         cannot be opened, None is returned.
-
-    Description
-    -----------
-    This function will find a desired resource file and return an opened file
-    object. The main method of finding the resource uses the pkg_resources
-    resource_stream method, which searches your working set for the installed
-    project specified and appends the resource_path given to the project
-    path, leading it to the file. If setuptools is not installed or it cannot
-    find/open the resource, find_resource will use the sys.path[0] to find the
-    resource if alt_path is defined.
     """
 
     try:
         # Get the image using the pkg_resources resource_stream module, which
-        # will find the file by getting the Chaco install path and appending the
-        # image path. This method works in all cases as long as setuptools is
-        # installed. If setuptools isn't installed, the backup sys.path[0]
+        # will find the file by getting the Chaco install path and appending
+        # the image path. This method works in all cases as long as setuptools
+        # is installed. If setuptools isn't installed, the backup sys.path[0]
         # method is used.
         from pkg_resources import resource_stream, working_set, Requirement
 
@@ -159,7 +158,7 @@ def find_resource(project, resource_path, alt_path=None, return_path=False):
         # script is called directly from the command line using
         # 'python %SOMEPATH%/<script>'
         if alt_path is None:
-            return
+            return None
         if return_path:
             return os.path.join(sys.path[0], alt_path)
 
@@ -167,7 +166,7 @@ def find_resource(project, resource_path, alt_path=None, return_path=False):
         try:
             return open(os.path.join(sys.path[0], alt_path), "rb")
         except:
-            return
+            return None
 
 
 def store_resource(project, resource_path, filename):
@@ -188,8 +187,7 @@ def store_resource(project, resource_path, filename):
             % (project, resource_path)
         )
 
-    fo = open(filename, "wb")
-    fo.write(fi.read())
-    fo.close()
+    with open(filename, "wb") as fo:
+        fo.write(fi.read())
 
     fi.close()
